#!/bin/bash
#
# build static tools
# 05/2007 by Enno Ewers
#
# $Id: build.sh,v 1.11 2008/08/08 08:16:02 enno Exp $
#

mkdir bin || rm bin/*
mkdir build || rm -fr build/*

extractgz() {
    ( cd build && tar xvzf "../src/$1" ) || die "$1"
}

extractbz() {
    ( cd build && tar xvjf "../src/$1" ) || die "$1"
}

inst() {
    echo "Installing $*"
    strip "$@"
    chmod +x "$@"
    cp "$@" bin/ || die "install $@"
}

die() {
    echo "Error during build of $@" 1>&2
    exit 1
}

# sysvinit
extractgz sysvinit-2.86.tar.gz
( cd build/sysvinit-2.86/src && make last LDFLAGS=-static ) || die sysvinit
inst build/sysvinit-2.86/src/last

# coreutils 
extractgz coreutils-6.12.tar.gz
( cd build/coreutils-6.12 && env LDFLAGS=-static ./configure && make ) || die coreutils
inst build/coreutils-6.12/src/{base64,cat,cp,date,dd,df,du,echo,id,head,ls,md5sum,printenv,pwd,sha1sum,sha256sum,tail,test,tee,tr,true,false,uname,uptime,who}
inst build/coreutils-6.12/src/{basename,chgrp,chmod,chown,cut,env,kill,mkfifo,mknod,mkdir,mv,ln,rm,rmdir,sort,stty,su,sum,sync,touch,tty,uniq,wc}

# bash
extractgz bash-3.2.tar.gz
( cd build/bash-3.2 &&
    for patch in 001 002 003 004 005 006 007 008 009 010 011 012 013 014 015 016 017 018 019 020 021 022 023 024 025 026 027 028 029 030 031 032 033 034 035 036 037 038 039; do
	patch -p0 < "../../src/bash32-$patch" || die bash
    done
    ) || die bash
( cd build/bash-3.2 && ./configure --without-bash-malloc --enable-static-link && make ) || die bash
inst build/bash-3.2/bash

# grep
extractgz grep-2.5.3.tar.gz
( cd build/grep-2.5.3 && ./configure LDFLAGS=-static && make ) || die grep
inst build/grep-2.5.3/src/grep

# lsof
extractgz lsof_4.80.tar.gz
(cd build/lsof_4.80 && tar xvf lsof_4.80_src.tar) || die lsof
(cd build/lsof_4.80/lsof_4.80_src && ./Configure -n linux && make "`grep ^CFGL= Makefile` -static" ) || die lsof
inst build/lsof_4.80/lsof_4.80_src/lsof

# memdump
extractgz memdump-1.01.tar.gz
(cd build/memdump-1.01 && env XFLAGS=-static make) || die memdump
inst build/memdump-1.01/memdump

# net-tools
extractbz net-tools-1.60.tar.bz2
patch -p0 <<'EOF' || die net-tools
--- build/net-tools-1.60/hostname.c.orig	2008-06-19 14:04:01.000000000 +0200
+++ build/net-tools-1.60/hostname.c	2008-06-19 14:04:34.000000000 +0200
@@ -98,6 +98,7 @@
 	    fprintf(stderr, _("%s: name too long\n"), program_name);
 	    break;
 	default:
+	    ;
 	}
 	exit(1);
     };
@@ -117,6 +118,7 @@
 	    fprintf(stderr, _("%s: name too long\n"), program_name);
 	    break;
 	default:
+	    ;
 	}
 	exit(1);
     };
@@ -174,6 +176,7 @@
 	printf("%s\n", hp->h_name);
 	break;
     default:
+	;
     }
 }
EOF
patch -p0 <<'EOF' || die net-tools
--- build/net-tools-1.60/lib/x25_sr.c.orig	2008-06-19 14:03:21.000000000 +0200
+++ build/net-tools-1.60/lib/x25_sr.c	2008-06-19 14:03:32.000000000 +0200
@@ -77,7 +77,7 @@
   rt.sigdigits=sigdigits;
 
   /* x25_route_struct.address isn't type struct sockaddr_x25, Why? */
-  memcpy(&rt.address, &sx25.sx25_addr, sizeof(x25_address));
+  memcpy(&rt.address, &sx25.sx25_addr, sizeof(struct x25_address));
 
   while (*args) {
 	if (!strcmp(*args,"device") || !strcmp(*args,"dev")) {
EOF
patch -p0 <<'EOF' || die net-tools
--- build/net-tools-1.60/lib/inet_sr.c.orig	2008-06-19 13:55:46.000000000 +0200
+++ build/net-tools-1.60/lib/inet_sr.c	2008-06-19 13:55:59.000000000 +0200
@@ -105,6 +105,7 @@
     case 2:
        isnet = 0; break;
     default:
+	;
     }
 
     /* Fill in the other fields. */
EOF
cat > build/net-tools-1.60/config.h <<'EOF' || die net-tools
#define I18N 0

#define HAVE_AFUNIX 1
#define HAVE_AFINET 1
#define HAVE_AFINET6 1
#define HAVE_AFIPX 1
#define HAVE_AFATALK 1
#define HAVE_AFAX25 1
#define HAVE_AFNETROM 0
#define HAVE_AFROSE 0
#define HAVE_AFX25 1
#define HAVE_AFECONET 0
#define HAVE_AFDECnet 0
#define HAVE_AFASH 0

#define HAVE_HWETHER 1
#define HAVE_HWARC 1
#define HAVE_HWSLIP 1
#define HAVE_HWPPP 1
#define HAVE_HWTUNNEL 1
#define HAVE_HWSTRIP 1
#define HAVE_HWTR 1
#define HAVE_HWAX25 1
#define HAVE_HWROSE 0
#define HAVE_HWNETROM 1
#define HAVE_HWX25 1
#define HAVE_HWFR 1
#define HAVE_HWSIT 0
#define HAVE_HWFDDI 0
#define HAVE_HWHIPPI 0
#define HAVE_HWASH 0
#define HAVE_HWHDLCLAPB 0
#define HAVE_HWIRDA 1
#define HAVE_HWEC 0

#define HAVE_FW_MASQUERADE 0
#define HAVE_IP_TOOLS 0
#define HAVE_MII 0
EOF
cat > build/net-tools-1.60/config.make <<'EOF'
# I18N=0
HAVE_AFUNIX=1
HAVE_AFINET=1
HAVE_AFINET6=1
HAVE_AFIPX=1
HAVE_AFATALK=1
HAVE_AFAX25=1
# HAVE_AFNETROM=0
# HAVE_AFROSE=0
HAVE_AFX25=1
# HAVE_AFECONET=0
# HAVE_AFDECnet=0
# HAVE_AFASH=0
HAVE_HWETHER=1
HAVE_HWARC=1
HAVE_HWSLIP=1
HAVE_HWPPP=1
HAVE_HWTUNNEL=1
HAVE_HWSTRIP=1
HAVE_HWTR=1
HAVE_HWAX25=1
# HAVE_HWROSE=0
HAVE_HWNETROM=1
HAVE_HWX25=1
HAVE_HWFR=1
# HAVE_HWSIT=0
# HAVE_HWFDDI=0
# HAVE_HWHIPPI=0
# HAVE_HWASH=0
# HAVE_HWHDLCLAPB=0
HAVE_HWIRDA=1
# HAVE_HWEC=0
# HAVE_FW_MASQUERADE=0
# HAVE_IP_TOOLS=0
# HAVE_MII=0
EOF
(cd build/net-tools-1.60 && make LOPTS=-static) || die net-tools
inst build/net-tools-1.60/{arp,hostname,ifconfig,netstat,route}

# pciutils
extractgz pciutils-3.0.0.tar.gz
(cd build/pciutils-3.0.0 && env LDFLAGS=-static make ZLIB=no) || die pciutils
inst build/pciutils-3.0.0/lspci

# procps
extractgz procps-3.2.7.tar.gz
(cd build/procps-3.2.7 && make LDFLAGS=-static SHARED=0) || die procps
inst build/procps-3.2.7/{ps/ps,sysctl,w}
inst build/procps-3.2.7/{free,top,uptime,watch,vmstat}

# coroners toolkit
extractgz tct-1.18.tar.gz
(cd build/tct-1.18 && make "CC=gcc -static") || die "coroners toolkit"
inst build/tct-1.18/bin/{pcat,icat,md5,ils}

# util-linux
extractgz util-linux-2.12r.tar.gz
patch -p0 <<'EOF' || die util-linux
--- build/util-linux-2.12r/Makefile.orig	2008-06-19 14:56:00.000000000 +0200
+++ build/util-linux-2.12r/Makefile	2008-06-19 14:56:10.000000000 +0200
@@ -15,7 +15,6 @@
 	login-utils \
 	misc-utils \
 	mount \
-	fdisk \
 	hwclock \
 	sys-utils \
 	text-utils
EOF
(cd build/util-linux-2.12r && make LDFLAGS=-static) || die util-linux
inst build/util-linux-2.12r/mount/{mount,umount,losetup}
inst build/util-linux-2.12r/hwclock/hwclock
inst build/util-linux-2.12r/sys-utils/dmesg
inst build/util-linux-2.12r/text-utils/{hexdump,more,tailf}
inst build/util-linux-2.12r/misc-utils/script

# sharutils
extractgz sharutils-4.6.3.tar.gz
(cd build/sharutils-4.6.3 && env LDFLAGS=-static ./configure && make) || die sharutils
inst build/sharutils-4.6.3/src/{uuencode,uudecode}

# precompiled tools
bzip2 -kd src/pd_v1.1_lnx.bz2
inst src/pd_v1.1_lnx
